"""Discovergy API."""

from pydiscovergy.discovergy import Discovergy

__all__ = [
    "Discovergy",
]
